---
layout: default
title: Academic Conduct
description: Expectations regarding plagiarism, LLM use and so on
(no)warning: old
---

Integrity is a crucial part of your character and is essential for
a successful career. We expect you to demonstrate integrity in
this class and elsewhere.

The Paul G Allen School has an [Academic
Misconduct](https://www.cs.washington.edu/academics/misconduct)
policy, and the University of Washington an [Academic
Misconduct](https://www.washington.edu/cssc/for-students/academic-misconduct/)
and [Community Standards and Student Conduct
Page](https://www.washington.edu/cssc/) policy. Please acquaint
yourself with those pages, and in particular how academic misconduct
will be reported to the University. Knowingly violating any of these principles of academic conduct,
privacy or copyright may result in University disciplinary action
under the Student Code of Conduct.


Your academic conduct in this course is evaluated in at least the
four areas described in detail below.

* TOC
{:toc}

# Honesty and Respect in Communications

Individuals are expected to be honest and forthcoming
in communications with TAs and the instructor. 

In addition, individuals are expected to show respect for the
intellectual contributions of others through citation. The essence of
academic life revolves around respect not only for the ideas of
others, but also their rights to those ideas. It is therefore
essential that we take the utmost care that the ideas (and the
expressions of those ideas) of others always be handled appropriately,
and, where necessary, cited. This is an issue of [Citational
Justice](nature.com/articles/d41586-022-00793-1), and a core value of
this course. It is also in line with the disability justice values of the course. 

When ideas or materials of others are
used (particularly in your creative projects), they must be cited. The
citation format is not that important - as long as the source material
can be located and the citation verified, it's OK. In any situation,
if you have a question, please feel free to ask. Here are some examples of how you might use (and cite) different types of content:

- Media you have created or generated yourself (i.e. pictures you have created or taken yourself, text you have written yourself) do generally not require citation. However if you have published them (on a blog, in an article etc), they may belong to the publisher and require citation.
-  Images that are in the public domain (something from Wikipedia), or with a creative commons license that allows for reuse without explicit permission of the owner, require citation based on their license. Instructions on how to search for images that are fair use are [here](https://support.google.com/websearch/answer/29508?hl=en). [Creative Commons Kiwi](https://creativecommons.org/about/videos/creative-commons-kiwi/) is a really informative video on Creative Commons licensing; and here are [best practices](https://wiki.creativecommons.org/wiki/Best_practices_for_attribution) for citing Creative Commons works.
- If you are writing some text (a paper, analysis, etc), you can use quotes as long as you give attribution to the sources of the quote. You can not write an entire document out of the quotes of others, or include copied text with no citations. The citation format is not that important - as long as the source material can be located and the citation verified (a url in a comment is generally fine), it's OK. 
- If you are writing code, clearly indicate (e.g. with comments) which portions of your code are completely original and which are used or modified from external sources, if any code is used that builds off of/is inspired by external sources (e.g. adaption of an example exercise, online tutorial you find). Note that solely changing identifier names or rearranging other source material is not considered your original work - see the examples of appropriate use below for details.

Some examples of appropriate use:
- A student finds a blog post explaining why and how to address WCAG guidelines. They rewrite much of it in their own words, but for a few sections that are particularly clear, they copy the information, put it in quotations, and name the source and provide a link to it right next to the quote.
- A student closely follows a tutorial to understand a new concept in  Android Development (e.g.  animations). The student cites the tutorial they used in the file header then substantially modifies the tutorial code to include what is specified for the creative portion of the assignment, documenting which portions of the code are their own so TAs know which portions to grade (and to determine whether the material cited as being learned from the tutorial is sufficiently adapted to be considered the student’s own work).
- A student is having difficulty generating audio from text for an accessibility feature of an app they are building. They look for a solution and find an app very similar to the one they intend to build. They fork it, and modify it for their final project, and documents this with a comment that includes where it was found. When grading the app, the instructional staff may weight features that were provided by the original source  less than features that the student added themselves.

Students with questions about any specific situation should ask the instructor for clarification.

# Collaboration Policies

In this class, are encouraged to  discuss class material, including
assignments, lecture material and readings with your classmates. Even
better if this takes place on Ed where other students can benefit and
we can guide you as to what is supportive and what crosses the line to
too much sharing.

Some assignments are individual. Even when as assignment is
individual, you **may discuss homework assignments with other
students** (i.e. provide advice, brainstorm) as long your writing
and/or implementation is entirely your own, and you document what you
do. You may also look at other sources online to learn how to achieve
new things, but we expect you to document this, and it may impact the
credit you get for your work. You should never copy (plagiarize) from
another person in this school (past or present) or from material that
you find online directly and submit it as your own work.

To facilitate this, and to be very clear 
- You **may not use code or writing directly from any external
  sources** (including copying lecture/lab material directly into an
  assignment) without appropriately crediting the source as described above in <q>Honesty and Respect in Communications</q>
- You must credit a classmate when their advice had a significant intellectual impact on what you did

# Chat GPT

It is hard to find someone who has not heard about ChatGPT and related tools, and these tools are undeniably useful for generating ideas, providing suggestions, and more. In this class, we will ask you to follow these ethical guidelines when using generative AI such as ChatGPT.  

1. Whether you use generative AI or read someone's blog post or code, you are expected to ensure that the final product is your own, original work. 
2. You may use generative AI for assignments and exams unless I specify that it may not be used. If guidelines are provided you should additionally follow those guidelines. 
3. Unlike blog posts and research articles, you do not need to attribute artifacts/quote text or label code produced by generative AI when you use it.  However, you must do the following or you will face academic consequences including but not limited to failing an assignment or an exam. 
 - You must cite the AI program you used in the artifact you hand in
 - If it copies text from other sources and you don't provide proper attribution, you will be held accountable for that. 
 -  If it provides ideas that are not your own, you will need to find and properly cite the original source. 
 - You must still comply with the academic integrity policies of the institution. This includes refraining from using generative AI to plagiarize or cheat.

3. You will be held to the same standards when you use generative AI as for any assignment, regardless of whether you or the AI created something, including:
 - If you turn in artifacts that are not accessible, you will be graded accordingly
 - If you turn in artifacts that contain false or incomplete claims, you will be graded accordingly
 - If you turn in code that does not compile or is incomplete, you will be graded accordingly
 - You will be graded based on the critical thinking and writing skills, accuracy, and accessibility of the things that you produce. 
  
We recommend that you use generative AI in moderation. Generative AI can help you to summarize text, improve grammer, write code, collect relevant resources to read, and generate ideas. However if you start to rely solely on it, you may limit your own development in critical thinking and writing, and if the results are that your writing is narrower and shallower in scope this may impact your grade. 

Also please note that using such tools may imply donating your data to the companies that deployed them. Please take reasonable steps to avoid making our assignments easier in future iterations of the course (e.g., once the tool provides a correct answer, don't give it positive feedback).

To summarize, you may use generative AI unless otherwise specified. However, you must use it ethically, check its work, and ensure that you do not cheat or plagiarize when using it. Further, you will most likely not receive a high grade if you rely on it to the exclusion of your own critical thinking, writing and accessibility skills. 

# Privacy and Fair Use

To support an academic environment of rigorous discussion and open
expression of personal thoughts and feelings, we, as members of the
academic community, must be committed to the inviolate right of
privacy of our student and instructor colleagues. As a result, we must
forego sharing personally identifiable information about any member of
our community including information about the ideas they express,
their families, lifestyles and their political and social
affiliations. If you have any questions regarding whether a disclosure
you wish to make regarding anyone in this course or in the university
community violates that person's privacy interests, please feel free
to ask the instructor for guidance.

In addition, out of respect for each other, and in accordance with
federal guidelines such as FERPA, we will not share each other's
discussion posts or assignments without permission. As instructors, we will 
ask you before sharing an assignment with a community sponser, for example.
Similarly, you should not share your fellow classmates' work without permission, and credit.
We also ask that you not share the ideas ideas presented in this class without credit.
While the class website is public, we ask that you do not take things out of context.

In addition, any tangible medium such as digital and physical documents are
protected by copyright law as embodied in title 17 of the United
States Code. These expressions include the work product of both:
(1) your student colleagues (e.g., any assignments published here
in the course environment or statements committed to text in a
discussion forum); and, (2) your instructor (e.g., the syllabus,
assignments, reading lists, and lectures). 

Within the constraints of <q>fair use,</q> you may copy these
copyrighted expressions for your personal intellectual use in support
of your education here in the UW. Such fair use by you does not
include further distribution by any means of copying, performance or
presentation beyond the circle of your close acquaintances, student
colleagues in this class and your family. If you have any questions
regarding whether a use to which you wish to put one of these
expressions violates the creator's copyright interests, please feel
free to ask the instructor for guidance.

# Appropriateness

Recall that one of our course policies is to engender an
inclusive environment. As such it is important that you are thoughtful about
what you say or write. Please make sure that 
images and text you are using are <q>school appropriate</q> and follow
the guidelines of expected behavior. If you have any questions,
please do not hesitate to ask the TA or your instructor. Inappropriate work
submitted may be ineligible for credit on that assignment.

