---
layout: assignment
published: true

title: AT Around Us
description: Find and learn about how people with disabilities use a variety of accessibility technologies
code: hw1

assigned: 9/29/2023
due: 
   - Slides October 5, 2023, 3:30pm (1 day grace period)
   - Presentation October 6, 2023 (no grace period, you present in class)
 
revised: August 3, 2023

---

* TOC
{:toc}


# Overview

The goal of this assignment is give you experience with seeking out first-person accounts of disability experiences with technology. It will also give you experience with presenting accessibly and expose you to a wide range of accessibility technologies. 


## Learning Goals/ Competencies
This homework may contribute to your competency grade on 
- Image description
- Accessible presentation creation 
- Presenting accessibly to an audience with mixed disabilities
- Finding first person accounts by and for people with disabilities
- Familiarity with a range of accessibility technologies (requires being present and engaged with student presentations) 
- Your participation grade, as a percentage of completeness (are all the required parts present)

## Length and Difficulty
Students in the past have reported that this assignment takes an median of 4 hours (mode=3). However, in our experience many students have to make multiple attempts to fully meet the competency for finding first person accounts. We recommend you carefully read the requirements for that below, and check in if you have a question. Many students also found presenting accessibly difficult, particularly with respect to how to describe images on their slides. We recommend that you practice this ahead of time. 
Some things students have told us about this assignment:
- "I like the requirement of looking at real world tools or tech, expanding beyond the computer."
- "I enjoy doing this because I watched a few videos and learned a lot of accessibility technology tools [and why we have them]."
- "It was surprisingly difficult to find first-person accounts for the tech I chose."

# Details

To complete this assignment you will need to do the following: 

## 0. Learn about how to present accessibly

Watch [a video about presenting
accessible](https://www.youtube.com/watch?v=L9TxhGv91kc) by Kyle
Rector and look at [DOIT's](https://www.washington.edu/doit/tips-delivering-accessible-presentation#:~:text=Provide%20attendees%20materials%20(ideally%2C%20ahead,time%20captioners%20materials%20in%20advance.) guidance no accessible presenting. Review information about [describing images](https://webaim.org/techniques/alttext/) and [describing people](https://www.youtube.com/watch?v=By6nzFefcxs) in images verbally (during a presentation) or in text. Finally, make sure you don't use [ableist language](https://www.popsugar.com/fitness/common-phrases-that-are-ableist-48080654). 

Optional reading [Its complicated: Negotiating Accessibility and
(Mis)Representation in Image Descriptions of Race, Gender and
Disability](https://guoanhong.com/papers/CHI21-ImageDescriptions.pdf)


## 1. Select two examples of an accessibility technology or disability hack

Select two examples of accessibility technology, or disability hack, that you will be presenting about. An accessibility technology is something that is used by a person with a disability to increase accessibility. It can be something that is included in the infrastructure (such as a [curb cut](https://en.wikipedia.org/wiki/Curb_cut)) or something that is used by an individual (such as [Proloque2Go](https://www.talktometechnologies.com/pages/proloquo2go), a symbol-based communication system), or something that was not designed for accessibility bit is useful (such as these [5 disability life hacks](https://www.spinalcord.com/blog/5-inexpensive-disability-life-wheelchair-hacks))

When you pick, consider **these requirements**
- One technology should improve computer access (such as [sticky keys](https://en.wikipedia.org/wiki/Sticky_keys).
- One should improve access to "the world" at large (such as Microsoft's [Seeing AI](https://www.microsoft.com/en-us/ai/seeing-ai)).
- At least one should involve computers in some way (such as [sticky keys](https://en.wikipedia.org/wiki/Sticky_keys).
- Try not to pick the same thing as someone else in the class.
- Do not choose really really common things (like elevators and glasses). 
- Do not pick a [*Disability Dongle*](https://blog.castac.org/2022/04/disability-dongle/)
- At least one of your chosen technologies is something you can try yourself

In addition, you should pick something that *expands your knowledge of accessibility technology.* You should include two different technologies that you are not already familiar with. Other ideas to consider when searching for technology:
- Does it address infrastructure (like curb cuts) or is it more individual (like a screen magnifier)? 
- Was it designed for the disability community (like a screen reader) or is it a mainstream technology being used to address accessibility needs (like [voice assistants have](https://dl.acm.org/doi/pdf/10.1145/3173574.3174033)).

## 2. Find and Generate First Person Experiences

Find first person accounts *by a person with a disability* that is *not an advertisement* describing each technology and how they use it. A first person account is written or presented by someone who
- Uses this technology themselves on a regular basis
- has a disability

A first person account that meets the requirements of this assignment is not
- a teaching video/presentation
- an advertisement.
- based on your personal experience 

For example, here is a [personal perspective on audio crosswalks](https://www.youtube.com/watch?v=xPlsYhU1HBU) and here is an interview with two black AAC users about their experiences using AAC technology (start at 00:16:00)

<iframe width="560" height="315" src="https://www.youtube.com/embed/iTSAK4yRf5A" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>

Ideally, you will find a video account showing the technology in use. Try searching for "howto" or try searching first for vloggers who have a disability, and then looking in their channels for technology reviews. Also ask for help on our [discussion site]({{site.discussion}}) if you are having trouble. If you cannot find a video, you can look for a written account, such as a blog or review. In this case, it still needs to be written by a personal with a disability who would benefit from the AT that you are trying to learn about. This may influence your choice of technologies, it is OK to iterate. 

## 3. Try it yourself 

While some technologies may be expensive or hard to get, many accessibility technologies are easily available and some are even re-purposed everyday items. Try at least one of the technologies you find yourself. 

## 3. Reflect on What you Learned

Take some time to reflect on these questions, which will help you to prepare for your presentation

What is the AT?
- What is the technology?
- What does the AT do?
- What is the access gap that the AT is attempting to address?
- Why was it developed?
- What are it's strengths and/or weaknesses?

How did your experience using it differ from the first person account you saw?

Which disabilities does this technology support? Think broadly about
this, and try to find evidence for your ideas. For example, audio
books and screen readers are used by people who are blind or low vision, as well as people who
are dyslexic, or cannot look at a screen without experiencing chronic
illness symptoms.

If you have a chance to interview users of this technology, what would be one question you would ask, that was not answered in your search for information?

## 4. Create two slides, one for each technology you found

You will create one accessible slides (per AT) in a shared slide deck posted in the [Class Discussion]({{site.discussion}}) and on [Canvas]({{site.canvas}}). Your slide should include 
- A summary of the AT you researched 
- Information about its audience (range of disabilities that use it)
- A picture of it
- A link to the first person account you found
- Something you learned from the video and/or by trying it about its strengths and weaknesses

Make sure the slides are accessible. 

# Turnin

1. You will turn the slide in by adding it to the shared slide deck
2. You will also present at least one of those slides in class. You should be prepared to 
- Stay on time (3-4 minutes + 1-2 minutes of questions). This will require you to pick and choose what to focus on when you design your slide, and to practice ahead of class.
- Present accessibly (you may want to revisit  [presenting accessible](https://www.youtube.com/watch?v=L9TxhGv91kc) by Kyle Rector)
