---
layout: default
title: Schedule
description: Class schedule and links to lectures, readings and assignments
warning: draft
---

* TOC
{:toc}

{: .module} 
# Module 1: Accessibility Basics 

{: .week}
# Week 1 (9/27 - 9/29): Introduction to Disability & Accessibility

{% details Learning Goals %} 
- What is Disability?
- What is Accessibility?
- What are Accessibility Technologies?
{% enddetails %}

{% details Wednesday: Overview of course  & Introduction to Disability %} 

: **Slides** {% include slide.html title="Introduction to Course" loc="introduction.html" %}

{: .homework} Required Reading and Reflection
: 

- **Required**
   -  Read about [Disability Dongles](https://www.vox.com/first-person/2019/4/30/18523006/disabled-wheelchair-access-ramps-stair-climbing)  and  [**Respond**](TBD)
- **If you want to dig deeper**
   - Defining Article [Disability Dongles](https://blog.castac.org/2022/04/disability-dongle/) by Liz Jackson 
   
{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}

{% details Thursday: Section %} 
TBD (possibly trying out accessibility technologies)
{% enddetails %}

{% details Friday: Accessibility Technology %} 

**Slides** {% include slide.html title="In Class Activities" loc="accessibility.html" %}

{: .homework} [AT Around Us](assignments/finding-accessibility.html) Assigned: Find Accessibility Technologies
: 

{: .homework} [Class Participation survey](TBD)
: 

{% enddetails %}

{: .week}
# Week 2 (10/2 - 10/6): Accessible Documents & Disability Justice

{% details Learning Goals %} 
We will start understanding how to make documents accesible
- How to present accessibly
- Get comfortable with basic image  description (images, people)
- Plain Language 
And study disability justice
- Understand models for disability-centered design
- What is Disability Justice 
{% enddetails %}


{% details Monday 10/2: Accessible Presentations and Plain Language%} 

- **Slides** {% include slide.html title="Accessible Presentations and Presenting Accessibly" loc="presenting-accessibly.html" %}
- (if time) start on - **Slides** {% include slide.html title="Introduction to Plain Language" loc="disability-justice.html" %}

{: .homework} Required Reading and Reflection (for Wednesday)
: 

- **Required**
  -  The [10 principles of disability justice](https://static1.squarespace.com/static/5bed3674f8370ad8c02efd9a/t/5f1f0783916d8a179c46126d/1595869064521/10_Principles_of_DJ-2ndEd.pdf) and post your [Reflection](tbd)
- **If you want to dig deeper**
  - [Design, Disability and Knowing the 'Other'](TBD) and  [**Respond**](TBD)

{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}

{% details Wednesday 10/4: Plain Language and Disability Justice %} 

- Finish **Slides** {% include slide.html title="Introduction to Plain Language" loc="disability-justice.html" %}
- **Slides** {% include slide.html title="Introduction to Plain Language" loc="plain-language.html" %}

{: .homework} [Disability Justice Homework](assignments/disabilityjustice.html) Assigned: Pick an access topic and analyze it from a disability justice perspective.
: 

{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}

{% details Thursday: Section %} 
Practice with Plain Language
{% enddetails %}


{% details Friday 10/2: AT Around Us Presentations %} 

   
{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}

{: .week}
# Week 3 (10/9-10/13): Accessibility Assessment 1: Guidelines and Assessment

{% details Learning Goals %} 
- What are the current accessibility standards
- How do we use automated tools to assess accessibility
- How can we use accessibility technology to assess accessibility
- Get comfortable using existing freely available accessibility technology to support assessment
- More advanced accessibility techniques
    - Differences between Image description, Diagram description and UI description
    - Video description & Captioning
    - Math, Tables & other elements (including custom interactors)
{% enddetails %}

{% details Monday 10/2: Accessibility Testing %} 

- **Slides** {% include slide.html title="Accessibility Testing" loc="testing.html" %}

{: .homework} Required Reading and Reflection (for Wednesday)
: 

- **Required**
  - Accessibility Testing: Read [The importance of Manual Accessibility Testing](https://www.smashingmagazine.com/2018/09/importance-manual-accessibility-testing/) and [**Respond**](TBD)
  - Read about [creating accessible images and diagrams](https://dis.acm.org/2023/creating-accessible-figures-and-tables/) and [**Respond**](TBD)
       - Find a non-text content on the web that does not have ALT text (something other than a photograph)
       - [Post](https://edstem.org/us/courses/31170/discussion/2394641)) a description of [the leftmost GUI](img/assessment/gui.png) 
  - Audio Description: Read [What is audio description?](https://adp.acb.org/articles/adprocess.html) (from [The Audio Description Project](https://www.acb.org/adp/ad.html)) and [**Respond**](TBD)
  - Read the [Website Testing Homework](assignments/website.html) and [tell us the top 3 websites you'd like to be assigned to assess](TBD)
- **If you want to dig deeper**
   - Read about [Switches](https://axesslab.com/switches/)
   - Try out the [Image ALT Text Tutorial](https://webaim.org/techniques/alttext/) 
   - Watch: [Rescribe: Authoring and Automatically Editing Audio Descriptions](https://www.youtube.com/watch?v=jmyPmT5T0PY)

{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}

{% details Wednesday 10/4: Accessibility Standards %} 

{: .prepare} Come Prepared
: Come to class with an image, diagram, or other graphic you want to describe

**Slides** {% include slide.html title="Accessibility Standards & Media Accessibility" loc="assessment.html" %}

{: .homework} [Website Testing Homework](assignments/website.html) Assigned: Assess a website and generate UARS for it
: 

{: .homework} [Class Participation survey](TBD)
: 

{% enddetails %}
 
{% details Thursday: Section %} 
Practice with Accessibility Assesssment 
{% enddetails %}

{% details Friday 10/13: More Website Standards %} 

**Slides** {% include slide.html title="More Accessibility Standards" loc="assessment2.html" %}
   
{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}

{: .week}
# Week 4 (10/16-10/20): Building Accessible Interfaces & Remediating Problems

{% details Learning Goals %} 
- How accessibility works under the hood
- More on navigation and its impact 
- What are the tradeoffs between different tools?
{% enddetails %}

{% details Monday 10/16: What's the best way to Assess a Website?%} 

**Slides** {% include slide.html title="Comparing Automated Testing and Manual Testing" loc="comparing-approaches.html" %}

{: .homework} Required Reading and Reflection (for Wednesday)
: 

- **Required**
   - Read: About how [web semantics are conveyed to screen readers](https://alistapart.com/article/semantics-to-screen-readers/)   and [**Respond**](TBD) 
   - Read: [Accessibility in Software Practice: A Practitioner’s Perspective](https://dl.acm.org/doi/abs/10.1145/3503508) and Respond on Ed (TBD)
- **If you want to dig deeper**
   - Read: [Is your web page accessible? A comparative study of methods for assessing web page accessibility for the blind](https://dl.acm.org/doi/10.1145/1054972.1054979) and [**Respond**](TBD)
   - Read: [Comparison of different methods for accessibility testing](https://sol.sbc.org.br/journals/index.php/jis/article/view/1778/1848) Mateus etal, 2021 
   - Watch: [Google Video on Practical Web Accessibility](https://www.youtube.com/watch?v=x18vEEfpK3g) — this video provides a great overview of the Web and how to make web content accessible. Highly recommended as a supplement to what we will cover in class.
   - Watch: [Latte: Use-Case and Assistive-Service Driven Automated Accessibility Testing Framework for Android](https://www.youtube.com/watch?v=Z84jeO0UZFE) and read [Lies, Damned Lies, Overlays, and Widgets](https://www.linkedin.com/pulse/lies-damned-overlays-widgets-timothy-springer/)
   - Read: [Semantics for Eye tracking](https://dl.acm.org/doi/pdf/10.1145/3338844)

{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}

{% details Wednesday 10/18:  How to Build Accessible Interfaces %} 

**Slides** {% include slide.html title="How to build for accessibility" loc="best-practices.html" %}

{: .homework} [Website Report](assignments/website-report.html) Assigned: Write a group report about your assessment
: 

{: .homework} [Class Participation survey](TBD)
: 

{% enddetails %}
 
{% details Thursday: Section %} 
Group work on Report
{% enddetails %}

{% details Friday 10/20: More Website Standards %} 

**Slides** {% include slide.html title="More Accessibility Standards" loc="assessment2.html" %}
   
{: .homework} [Class Participation survey](TBD)
: 
   
{: .homework} **Post-module Reflection:**  [Accessibility Basics Reflection](https://forms.gle/Wk8C51m5Sbq8RX7W8)
: 

{% enddetails %}



{: .module} 
# Module 2: Post GUI Accessibility 

{: .week}
# Week 5 (10/23 - 10/27): Accessible Needfinding and Evaluation

{% details Learning Goals %} 
- How to assess whether a technology is accessible; and whether an accessibility technology is useful and usable, in an inclusive fashion.
- How do you make sure your *product is accessible* to people with disabilities
   1. Data Equity and implicit bias
   2. Beyond automated assessment: Accessible Summative Studies
   3. Importance of Intersectionality
- How do you make sure your *accessibility technology is valued* by people with disabilities
   - What are potential data sources for assessing value
   - Collaboration Versus Paternalism
   - Overly narrow views of disability: Multiple disabled people & multiply disabled people
{% enddetails %}

{% details Monday 10/23: Introduction to Assessing Accessibility} 

**Slides** {% include slide.html title="Assessing Accessibility" loc="evaluation.html" %}

{: .homework} Required Reading and Reflection (for Wednesday)
: 
- **Required Reading**
  - Read [Blurring the Boundaries Between Assistive Tech and Companionship](https://www.forbes.com/sites/gusalexiou/2021/01/26/amazon-alexa---blurring-the-boundaries-between-assistive-tech-and-companionship/?sh=3bf833b75e7b) and Respond
  - Read [How to do something good in the disability community if you're not disabled](https://www.forbes.com/sites/andrewpulrang/2020/12/16/how-to-do-something-good-in-the-disability-community-if-youre-not-disabled/?sh=21ef25c97d7f)
- **If you want to dig deeper**
  - Read [Anticipate and Adjust](https://dl.acm.org/doi/abs/10.1145/3491102.3501882)
  - Read [Accessibility came by accident](https://dl.acm.org/doi/pdf/10.1145/3173574.3174033?casa_token=T1I2RwihIjsAAAAA:QEm3SjurdlcW7oX_1LadxaglZ7oneBX-XLIjMCHbof3gu_IFpDW2OO5tqxZfLIps-94Qik9y5wNw8Q)

{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}

{% details Wednesday 10/25: Introduction to Designing for Accessibility %} 
: **Slides** {% include slide.html title="Designing for and with people with disabilities" loc="designing.html" %}

{: .homework} [Technology Review](assignments/technology-review.html) Assigned: Write a group report about your assessment
: 

{: .homework} [Class Participation survey](TBD)
: 

{% enddetails %}
 
{% details Thursday: Section %} 
TBD
{% enddetails %}

{% details Friday 10/27: Deaf Technology & Innovation (Tentative Guest Lecture Date -- Richard Ladner) %} 

{: .homework} [Class Participation survey](TBD)
: 

{% enddetails %}


{: .week}
# Week 6 (10/30 - 11/3): Accessible Visulaizations & AR/VR
{% details Learning Goals %} 

Accessible Data Visualizations
    - What are the commonly-used techniques to make data visualizations accessible?
    - What are the pros and cons of these techniques?
    - What are some of the nuances in making data visualizations accessible?

Learn about how to make AR/VR interfaces and games accessible
{% enddetails %}


{% details Monday 10/30: Data Equity %} 

**Slides** {% include slide.html title="Data Equity" loc="bias-in-machine-learning.html" %}

{: .homework} Required Reading and Reflection (for Wednesday)
: 

- **Required: Respond to the Reading Questions and Preparation Requirements.**
  - [Increasing Data Equity in Accessibility](https://arxiv.org/abs/2210.01902) No ed post for this one :)
- **If you want to go deeper**
  - [A systematic literature review of handheld augmented reality solutions for people with disabilities](https://www.mdpi.com/1424-8220/22/20/7719)
  - [Understanding Screen-Reader Users’ Experiences with Online Data Visualizations](https://athersharif.me/documents/assets-2021-understanding-sru-experiences-online-data-viz.pdf) [**Respond**](TBD)
  - [Data Representation in Accessibility Data Sets: A Meta-analysis](https://arxiv.org/abs/2207.08037) [**Respond**](TBD)
  - [The Future of Urban Accessibility for People with Disabilities: Data Collection, Analytic, Policy, and Tools](https://dl.acm.org/doi/fullHtml/10.1145/3517428.3550402)
  - [Rich Screen Reader Experiences for Accessible Data Visualization](https://arxiv.org/pdf/2205.04917.pdf)
  - [VoxLens: Making Online Data Visualizations Accessible With an Interactive JavaScript Plug-In](https://athersharif.me/documents/chi-2022-voxlens.pdf)

{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}


{% details Wednesday 11/1: AR/VR Accessibility %} 

**Slides** {% include slide.html title="AR/VR Accessibility" loc="arvr.html" %}



{: .homework} [Technology Review](assignments/technology-implementation.html) Assigned: Make something (post-gui) more accessible
: 

{: .homework} [Class Participation survey](TBD)
: 

{% enddetails %}
 
{% details Thursday: Section %} 
Practice with making data accessible

{% enddetails %}

{% details Friday 11/3: Technology-Implementation Meetings  %} 

Check in to make sure you have a plan and it is do-able

{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}


{: .week}
# Week 7 (11/6 - 11/10): Fabrication & Data Equity
{% details Learning Goals %} 
- Work with laser cutting to make accessible technology
- Learn about fabrication tools and techniques

- Bias in Machine Learning
    - What is Machine Learning (ML)? 
    - What are the components of ML?
    - How do we collect data? Who do we collect the data from?
    - Is the data "good"?
    - How do we minimize disability bias?
{% enddetails %}


{% details Monday 11/6: What's the best way to Assess a Website?%} 

**Slides** {% include slide.html title="Introduction to 3D Printing and Physical Computing" loc="3dprinting.html" %}

{: .homework} Required Reading and Reflection (for Wednesday)
: 

- **Required: Respond to the Reading Questions and Preparation Requirements.**
  - [Consumer-Grade Fabrication and Its Potential to Revolutionize Accessibility](https://dl.acm.org/doi/10.1145/3339824), CACM 2019  and [**Respond**](TBD)
  - [Areas of Strategic Visibility: Disability Bias in Biometrics](https://arxiv.org/abs/2208.04712) and [**Respond**](TBD)
- **If you want to go deeper**
  - [Explaining Explanations: An Approach to Evaluating Interpretability of Machine Learning](https://www.cs.purdue.edu/homes/bb/nit/Lalana-Explainations%20of%20IAS.pdf)
  - [Fairness issues in AI Systems that augment sensory abilities](https://arxiv.org/pdf/1908.07333.pdf) 

{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}

{% details Wednesday 11/8: Making a Laser Cut Book Opener %} 
Work in class on this


{: .homework} [Final Project Proposal](assignments/project-proposals.html) Assigned: Prepare your final project proposal (individual)
: 

{: .homework} [Class Participation survey](TBD)
: 

{% enddetails %}
 
{% details Thursday: Section %} 
Finish making laser cuttable designs and print

{% enddetails %}

## Friday 11/10: HOLIDAY
{: .holiday}

{: .week}

# Module 3: Everything Everywhere All at Once

{: .week}
# Week 8 (11/13-11/17): Chronic Illness  & Sustainability
{% details Learning Goals %}
- How to assess whether a technology is accessible; and whether an accessibility technology is useful and usable, in an inclusive fashion.
- How do you make sure your *product is accessible* to people with disabilities
   1. Data Equity and implicit bias
   2. Beyond automated assessment: Accessible Summative Studies
   3. Importance of Intersectionality
- How do you make sure your *accessibility technology is valued* by people with disabilities
   - What are potential data sources for assessing value
   - Collaboration Versus Paternalism
   - Overly narrow views of disability: Multiple disabled people & multiply disabled people
{% enddetails %}


{% details Monday 11/13: Group Formation %}

In class exercise to form final project groups

{: .homework} Required Reading and Reflection (for Wednesday)
: 
- **Required: Respond to the Reading Questions and Preparation Requirements on Ed**. There is only one Ed post you need to make this week in response to either or both assigned readings. [Please post your response in this Ed thread]({site.discussion}2649283)
  - [Difficulty Vs Accessibility](https://www.youtube.com/watch?v=sPehhHZvKE8&list=PLVEo4bPIUOskja9pfpqceY8qDrykFdubf&index=18)
  - [My Disability Is Dynamic](https://medium.com/age-of-awareness/my-disability-is-dynamic-bc2a619fcc1)
- **If you want to dig deeper**
  - [Considerations for HCI accessibility practices with chronically ill people](https://dl.acm.org/doi/abs/10.1145/3517428.3544803)

{: .homework} [Class Participation survey](TBD)
: 
{% enddetails %}

{% details Wednesday 11/15: Chronic Illness and Accessibility %}

**Slides** TBD

{: .homework} [Group Project Checkpoint](assignments/project-checkpoint.html) Assigned: Group Project Checkpoint
: 

{: .homework} [Final Project Handin](assignments/project-final.html) 
: 

{: .homework} [Class Participation survey](TBD)
: 

{% enddetails %}
 
{% details Thursday: Section %}
Work in groups on final projects

{% enddetails %}

{% details Friday 11/17: Sustainability  %}

**Slides** {% include slide.html title="Sustainability" loc="sustainability.html" %}

{: .homework} [Class Participation survey](TBD)
: 
   
{% enddetails %}

{: .week}
# Week 9 (11/20-11/24): Group  Checkpoint 1

{% details Monday 11/20: First Half of Group Presentations %}
Present in class
{% enddetails %}

{% details Wednesday 11/22: Second Half of Group Presentations %}
Present in class

{% enddetails %}
 
{% details Thursday: Section %}
Work in groups on final projects

{% enddetails %}

## Friday 11/24: HOLIDAY
{: .holiday}

{: .week}
# Week 10 (12/4--12/8): 1:1 Project Meetings / TBD
{% details Learning Goals: STILL TBD %}
TBD
{% enddetails %}


{: .week}
# Finals week: Final presentations -- time TBD

{: .lecture} Final project presentations
: 



# Unused Reading and Ideas
{% details some additional readings and slides to possibly use %}
- Physical computing slides
- [Crippin' Jim Crow](https://drive.google.com/file/d/1QaRu4T3aax6jg73quHKgpfwJe3nQ4PEv/view?usp=share_link) 
- [Traumatic Brain Injury: A Guide for Criminal Justice Professionals](https://www.brainline.org/article/traumatic-brain-injury-guide-criminal-justice-professionals)
- [Disabling Incarceration: Connecting Disability to Divergent Confinements in the USA](https://journals.sagepub.com/doi/pdf/10.1177/0896920511430864?casa_token=4JF2JifTBBwAAAAA:FOPw2ZwZDMbyKoRLloJIhzc4ZQTf25dnTt1NnvR6yaD-S8OfE96U-Un8QLA3_sOw7EGBk3ro8hUv)
- [A systematic literature review of handheld augmented reality solutions for people with disabilities](https://www.mdpi.com/1424-8220/22/20/7719) 
- [7 benefits of AR and VR for People with Disabilities](https://arpost.co/2022/02/09/7-benefits-ar-vr-for-people-with-disability/) (a bit ableist)
- [Living Disability Theory: Reflections on Research, Access and Design](https://make4all.org/wp-content/uploads/2020/09/hoffmann-living-disability-theory.pdf)
- [Disability Studies as a source of critical inquiry...](https://make4all.org/wp-content/uploads/2019/10/MankoffAssets2010.pdf)
- [Vital coronavirus is failing the blind and visually impaired](https://www.vice.com/en/article/4ag9wb/vital-coronavirus-information-is-failing-the-blind-and-visually-impaired)
- [Blurring the Boundaries Between Assistive Tech and Companionship](https://www.forbes.com/sites/gusalexiou/2021/01/26/amazon-alexa---blurring-the-boundaries-between-assistive-tech-and-companionship/?sh=2821499375e7) (a little too salesy)
{% enddetails %}

{% details slides not in use %}
**Slides** {% include slide.html title="Assessing Accessibility" loc="physical-computing.html" %}
{% enddetails %}


{% details topics not covered %}
- Video conferencing
-  Large gatherings (virtual or hybrid)
- Online text based support groups
- Social networks such as twitter or facebook 
- Crowdsourcing )
{% enddetails %}



